@@ -36,16 +36,6 @@ enum
   AFP_GET_USER_INFO_BITMAP_GET_UUID_BIT = 0x4
 };
 
-typedef enum
-{
-  AFP_MAP_ID_FUNCTION_USER_ID_TO_NAME         = 1,
-  AFP_MAP_ID_FUNCTION_GROUP_ID_TO_NAME        = 2,
-  AFP_MAP_ID_FUNCTION_USER_ID_TO_UTF8_NAME    = 3,
-  AFP_MAP_ID_FUNCTION_GROUP_ID_TO_UTF8_NAME   = 4,
-  AFP_MAP_ID_FUNCTION_USER_UUID_TO_UTF8_NAME  = 5,
-  AFP_MAP_ID_FUNCTION_GROUP_UUID_TO_UTF8_NAME = 6
-} AfpMapIDFunction;
-
 enum
 {
   AFP_MAP_NAME_FUNCTION_NAME_TO_USER_ID         = 1,
@@ -203,6 +193,7 @@ typedef enum
   AFP_COMMAND_GET_VOL_PARMS      = 17,
   AFP_COMMAND_LOGIN              = 18,
   AFP_COMMAND_LOGIN_CONT         = 19,
+  AFP_COMMAND_LOGOUT             = 20,
   AFP_COMMAND_MAP_ID             = 21,
   AFP_COMMAND_MAP_NAME           = 22,
   AFP_COMMAND_MOVE_AND_RENAME    = 23,
@@ -323,8 +314,8 @@ GType           g_vfs_afp_command_get_type (void) G_GNUC_CONST;
 #define G_VFS_TYPE_AFP_CONNECTION             (g_vfs_afp_connection_get_type ())
 #define G_VFS_AFP_CONNECTION(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), G_VFS_TYPE_AFP_CONNECTION, GVfsAfpConnection))
 #define G_VFS_AFP_CONNECTION_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), G_VFS_TYPE_AFP_CONNECTION, GVfsAfpConnectionClass))
-#define G_IS_VFS_AFP_CONNECTION(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), G_VFS_TYPE_AFP_CONNECTION))
-#define G_IS_VFS_AFP_CONNECTION_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), G_VFS_TYPE_AFP_CONNECTION))
+#define G_VFS_IS_AFP_CONNECTION(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), G_VFS_TYPE_AFP_CONNECTION))
+#define G_VFS_IS_AFP_CONNECTION_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), G_VFS_TYPE_AFP_CONNECTION))
 #define G_VFS_AFP_CONNECTION_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), G_VFS_TYPE_AFP_CONNECTION, GVfsAfpConnectionClass))
 
 typedef struct _GVfsAfpConnectionClass GVfsAfpConnectionClass;
@@ -352,23 +343,19 @@ GVfsAfpReply*      g_vfs_afp_query_server_info            (GSocketConnectable *a
 
 GVfsAfpConnection* g_vfs_afp_connection_new               (GSocketConnectable *addr);
 
-gboolean           g_vfs_afp_connection_open              (GVfsAfpConnection *afp_connection,
+gboolean           g_vfs_afp_connection_open_sync         (GVfsAfpConnection *afp_connection,
                                                            GCancellable      *cancellable,
                                                            GError            **error);
 
-gboolean           g_vfs_afp_connection_close             (GVfsAfpConnection *afp_connection,
+gboolean           g_vfs_afp_connection_close_sync        (GVfsAfpConnection *afp_connection,
                                                            GCancellable      *cancellable,
                                                            GError            **error);
 
-gboolean           g_vfs_afp_connection_send_command_sync (GVfsAfpConnection *afp_connection,
+GVfsAfpReply*      g_vfs_afp_connection_send_command_sync (GVfsAfpConnection *afp_connection,
                                                            GVfsAfpCommand    *afp_command,
                                                            GCancellable      *cancellable,
                                                            GError            **error);
 
-GVfsAfpReply*      g_vfs_afp_connection_read_reply_sync   (GVfsAfpConnection *afp_connection,
-                                                           GCancellable *cancellable,
-                                                           GError **error);
-
 GVfsAfpReply*      g_vfs_afp_connection_send_command_finish (GVfsAfpConnection *afp_connnection,
                                                              GAsyncResult      *res,
                                                              GError           **error);
@@ -379,6 +366,10 @@ void               g_vfs_afp_connection_send_command     (GVfsAfpConnection   *a
                                                           GAsyncReadyCallback  callback,
                                                           GCancellable        *cancellable,                                                           
                                                           gpointer             user_data);
+
+
+guint32            g_vfs_afp_connection_get_max_request_size  (GVfsAfpConnection *afp_connection);
+
 G_END_DECLS
 
 #endif /* _GVFSAFPCONNECTION_H_ */
